==> ejc-bidprice-api-3.0.0-20230209.114903-15-sources.jar: com/ejianc/business/bidprice/material/vo/MaterialResultRentDetailVO.java <==
package com.ejianc.business.bidprice.material.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 材料定标结果-租赁清单
 * 
 * @author generator
 * 
 */
@ApiModel("材料定标结果-租赁清单")
public class MaterialResultRentDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("定标结果主表id")
    private Long pid;
    @ApiModelProperty("来源定标采购子表id")
    private Long sourceId;
    @ApiModelProperty("物资分类Id")
    private Long materialCategoryId;
    @ApiModelProperty("物资分类名称")
    private String materialCategoryName;
    @ApiModelProperty("物资Id")
    private Long materialId;
    @ApiModelProperty("物资名称")
    private String materialName;
    @ApiModelProperty("规格型号")
    private String spec;
    @ApiModelProperty("计量单位")
    private String unit;
    @ApiModelProperty("租赁方式")
    private String rentMode;
    @ApiModelProperty("剩余采购数量")
    private BigDecimal residueNum;
    @ApiModelProperty("参考价")
    private BigDecimal referPrice;
    @ApiModelProperty("租期")
    private BigDecimal rentterm;
    @ApiModelProperty("中标数量")
    private BigDecimal bidNum;
    @ApiModelProperty("中标单价")
    private BigDecimal bidPrice;
    @ApiModelProperty("中标金额")
    private BigDecimal bidMny;
    

    /**
     * 定标结果主表id
     */
    public Long getPid() {
        return pid;
    }

    /**
     * 定标结果主表id
     */
    public void setPid(Long pid) {
        this.pid = pid;
    }
    /**
     * 来源定标采购子表id
     */
    public Long getSourceId() {
        return sourceId;
    }

    /**
     * 来源定标采购子表id
     */
    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 物资分类Id
     */
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    /**
     * 物资分类Id
     */
    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    /**
     * 物资分类名称
     */
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    /**
     * 物资分类名称
     */
    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    /**
     * 物资Id
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资Id
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 规格型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 计量单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 计量单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 租赁方式
     */
    public String getRentMode() {
        return rentMode;
    }

    /**
     * 租赁方式
     */
    public void setRentMode(String rentMode) {
        this.rentMode = rentMode;
    }
    /**
     * 剩余采购数量
     */
    public BigDecimal getResidueNum() {
        return residueNum;
    }

    /**
     * 剩余采购数量
     */
    public void setResidueNum(BigDecimal residueNum) {
        this.residueNum = residueNum;
    }
    /**
     * 参考价
     */
    public BigDecimal getReferPrice() {
        return referPrice;
    }

    /**
     * 参考价
     */
    public void setReferPrice(BigDecimal referPrice) {
        this.referPrice = referPrice;
    }
    /**
     * 租期
     */
    public BigDecimal getRentterm() {
        return rentterm;
    }

    /**
     * 租期
     */
    public void setRentterm(BigDecimal rentterm) {
        this.rentterm = rentterm;
    }
    /**
     * 中标数量
     */
    public BigDecimal getBidNum() {
        return bidNum;
    }

    /**
     * 中标数量
     */
    public void setBidNum(BigDecimal bidNum) {
        this.bidNum = bidNum;
    }
    /**
     * 中标单价
     */
    public BigDecimal getBidPrice() {
        return bidPrice;
    }

    /**
     * 中标单价
     */
    public void setBidPrice(BigDecimal bidPrice) {
        this.bidPrice = bidPrice;
    }
    /**
     * 中标金额
     */
    public BigDecimal getBidMny() {
        return bidMny;
    }

    /**
     * 中标金额
     */
    public void setBidMny(BigDecimal bidMny) {
        this.bidMny = bidMny;
    }
    
}

==> ejc-bidprice-api-3.0.0-20250917.075654-169-sources.jar: com/ejianc/business/bidprice/material/vo/MaterialResultRentDetailVO.java <==
package com.ejianc.business.bidprice.material.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 材料定标结果-租赁清单
 * 
 * @author generator
 * 
 */
@ApiModel("材料定标结果-租赁清单")
public class MaterialResultRentDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("定标结果主表id")
    private Long pid;
    @ApiModelProperty("来源定标采购子表id")
    private Long sourceId;
    @ApiModelProperty("物资分类Id")
    private Long materialCategoryId;
    @ApiModelProperty("物资分类名称")
    private String materialCategoryName;
    @ApiModelProperty("物资Id")
    private Long materialId;
    @ApiModelProperty("物资名称")
    private String materialName;
    @ApiModelProperty("规格型号")
    private String spec;
    @ApiModelProperty("计量单位")
    private String unit;
    @ApiModelProperty("租赁方式")
    private String rentMode;
    @ApiModelProperty("剩余采购数量")
    private BigDecimal residueNum;
    @ApiModelProperty("参考价")
    private BigDecimal referPrice;
    @ApiModelProperty("租期")
    private BigDecimal rentTerm;
    @ApiModelProperty("中标数量")
    private BigDecimal bidNum;
    @ApiModelProperty("中标单价")
    private BigDecimal bidPrice;
    @ApiModelProperty("中标金额")
    private BigDecimal bidMny;
    

    /**
     * 定标结果主表id
     */
    public Long getPid() {
        return pid;
    }

    /**
     * 定标结果主表id
     */
    public void setPid(Long pid) {
        this.pid = pid;
    }
    /**
     * 来源定标采购子表id
     */
    public Long getSourceId() {
        return sourceId;
    }

    /**
     * 来源定标采购子表id
     */
    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 物资分类Id
     */
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    /**
     * 物资分类Id
     */
    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    /**
     * 物资分类名称
     */
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    /**
     * 物资分类名称
     */
    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    /**
     * 物资Id
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资Id
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 规格型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 计量单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 计量单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 租赁方式
     */
    public String getRentMode() {
        return rentMode;
    }

    /**
     * 租赁方式
     */
    public void setRentMode(String rentMode) {
        this.rentMode = rentMode;
    }
    /**
     * 剩余采购数量
     */
    public BigDecimal getResidueNum() {
        return residueNum;
    }

    /**
     * 剩余采购数量
     */
    public void setResidueNum(BigDecimal residueNum) {
        this.residueNum = residueNum;
    }
    /**
     * 参考价
     */
    public BigDecimal getReferPrice() {
        return referPrice;
    }

    /**
     * 参考价
     */
    public void setReferPrice(BigDecimal referPrice) {
        this.referPrice = referPrice;
    }


    public BigDecimal getRentTerm() {
        return rentTerm;
    }

    public void setRentTerm(BigDecimal rentTerm) {
        this.rentTerm = rentTerm;
    }

    /**
     * 中标数量
     */
    public BigDecimal getBidNum() {
        return bidNum;
    }

    /**
     * 中标数量
     */
    public void setBidNum(BigDecimal bidNum) {
        this.bidNum = bidNum;
    }
    /**
     * 中标单价
     */
    public BigDecimal getBidPrice() {
        return bidPrice;
    }

    /**
     * 中标单价
     */
    public void setBidPrice(BigDecimal bidPrice) {
        this.bidPrice = bidPrice;
    }
    /**
     * 中标金额
     */
    public BigDecimal getBidMny() {
        return bidMny;
    }

    /**
     * 中标金额
     */
    public void setBidMny(BigDecimal bidMny) {
        this.bidMny = bidMny;
    }
    
}
